# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
 🎉 Start moving code from lamindb | [1](https://github.com/laminlabs/lndb-storage/pull/1) | [Koncopd](https://github.com/Koncopd) | 2022-11-20 |
